//
//  FlybitsConcierge.h
//  FlybitsConcierge
//
//  Created by Chirayu Patel on 2018-02-07.
//  Copyright © 2018 Flybits. All rights reserved.
//

#import <Foundation/Foundation.h>

//! Project version number for FlybitsConciergeSDK.
FOUNDATION_EXPORT double FlybitsConciergeSDKVersionNumber;

//! Project version string for FlybitsConciergeSDK.
FOUNDATION_EXPORT const unsigned char FlybitsConciergeSDKVersionString[];

// In this header, you should import all the public headers of your framework using statements like #import <FlybitsConciergeSDK/PublicHeader.h>
